@@ -1,16 +1,14 @@
 package Class::Accessor;
 require 5.00502;
 use strict;
-$Class::Accessor::VERSION = '0.34';
+$Class::Accessor::VERSION = '0.50';
 
 sub new {
-    my($proto, $fields) = @_;
-    my($class) = ref $proto || $proto;
-
-    $fields = {} unless defined $fields;
-
-    # make a copy of $fields.
-    bless {%$fields}, $class;
+    return bless
+        defined $_[1]
+            ? {%{$_[1]}} # make a copy of $fields.
+            : {},
+        ref $_[0] || $_[0];
 }
 
 sub mk_accessors {
@@ -245,7 +243,7 @@ __END__
   Foo->mk_accessors(qw(name role salary));
 
   # or if you prefer a Moose-like interface...
- 
+
   package Foo;
   use Class::Accessor "antlers";
   has name => ( is => "rw", isa => "Str" );
@@ -258,10 +256,10 @@ __END__
 
   my $job = $mp->role;  # gets $mp->{role}
   $mp->salary(400000);  # sets $mp->{salary} = 400000 # I wish
-  
+
   # like my @info = @{$mp}{qw(name role)}
   my @info = $mp->get(qw(name role));
-  
+
   # $mp->{salary} = 400000
   $mp->set('salary', 400000);
 
@@ -311,7 +309,7 @@ The basic set up is very simple:
 Done.  Foo now has simple far(), bar() and car() accessors
 defined.
 
-Alternatively, if you want to follow Damian's I<best practice> guidelines 
+Alternatively, if you want to follow Damian's I<best practice> guidelines
 you can use:
 
     package Foo;
@@ -337,7 +335,7 @@ Currently only the C<is> attribute is supported.
 
 Class::Accessor provides a basic constructor, C<new>.  It generates a
 hash-based object and can be called as either a class method or an
-object method.  
+object method.
 
 =head2 new
 
@@ -422,7 +420,7 @@ it will throw an exception.  It only uses set() and not get().
 
 B<NOTE> I'm not entirely sure why this is useful, but I'm sure someone
 will need it.  If you've found a use, let me know.  Right now it's here
-for orthoginality and because it's easy to implement.
+for orthogonality and because it's easy to implement.
 
     package Foo;
     use base qw(Class::Accessor);
@@ -504,9 +502,9 @@ override this method to change how data is stored by your accessors.
     $value  = $obj->get($key);
     @values = $obj->get(@keys);
 
-get() defines how data is retreived from your objects.
+get() defines how data is retrieved from your objects.
 
-override this method to change how it is retreived.
+override this method to change how it is retrieved.
 
 =head2 make_accessor
 
@@ -522,16 +520,16 @@ get() and set() before you start mucking with make_accessor().
 
     $read_only_accessor = __PACKAGE__->make_ro_accessor($field);
 
-Generates a subroutine refrence which acts as a read-only accessor for
+Generates a subroutine reference which acts as a read-only accessor for
 the given $field.  It only calls get().
 
 Override get() to change the behavior of your accessors.
 
 =head2 make_wo_accessor
 
-    $read_only_accessor = __PACKAGE__->make_wo_accessor($field);
+    $write_only_accessor = __PACKAGE__->make_wo_accessor($field);
 
-Generates a subroutine refrence which acts as a write-only accessor
+Generates a subroutine reference which acts as a write-only accessor
 (mutator) for the given $field.  It only calls set().
 
 Override set() to change the behavior of your accessors.
@@ -588,7 +586,7 @@ Here's an example of generating an accessor for every public field of
 your class.
 
     package Altoids;
-    
+
     use base qw(Class::Accessor Class::Fields);
     use fields qw(curiously strong mints);
     Altoids->mk_accessors( Altoids->show_fields('Public') );
@@ -604,7 +602,7 @@ your class.
     $tin->curiously('Curiouser and curiouser');
     print $tin->{curiously};    # prints 'Curiouser and curiouser'
 
-    
+
     # Subclassing works, too.
     package Mint::Snuff;
     use base qw(Altoids);
@@ -712,7 +710,7 @@ instead of the expected SUPER::email().
 
 =head1 AUTHORS
 
-Copyright 2009 Marty Pauley <marty+perl@kasei.com>
+Copyright 2017 Marty Pauley <marty+perl@martian.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.  That means either (a) the GNU General Public
